@@ -12,9 +12,24 @@ quad = function(formula) {
   for (i in 1:length(variables)) {
     for (j in i:length(variables)) {
       if (i == j) {
-        quadratic = paste(quadratic, " + I(", variables[i], "^2)", sep = "", collapse = "")
+        quadratic = paste(
+          quadratic,
+          " + I(",
+          variables[i],
+          "^2)",
+          sep = "",
+          collapse = ""
+        )
       } else {
-        quadratic = paste(quadratic, " + ", variables[i], ":", variables[j], sep = "", collapse = "")
+        quadratic = paste(
+          quadratic,
+          " + ",
+          variables[i],
+          ":",
+          variables[j],
+          sep = "",
+          collapse = ""
+        )
       }
     }
   }
