@@ -8,16 +8,24 @@ rearrange_formula_by_order = function(model, data) {
   interceptterm = attr(terms.formula(model, data = data), "intercept") == 1
   model_terms = attr(terms.formula(model, data = data), "term.labels")
   modelorder = attr(terms.formula(model, data = data), "order")
-  higherorderterms = grepl("^I\\(.+\\)$",
-                           x = attr(terms.formula(model, data = data), "term.labels"),
-                           perl = TRUE)
+  higherorderterms = grepl(
+    "^I\\(.+\\)$",
+    x = attr(terms.formula(model, data = data), "term.labels"),
+    perl = TRUE
+  )
   entries_move_end = (modelorder == 1 & higherorderterms)
-  rearranged_model = formula(paste0(c("~", paste0(c(model_terms[!entries_move_end],
-                                                    model_terms[entries_move_end]),
-                                                  collapse = " + ")),
-                                    collapse = ""))
+  rearranged_model = formula(paste0(
+    c(
+      "~",
+      paste0(
+        c(model_terms[!entries_move_end], model_terms[entries_move_end]),
+        collapse = " + "
+      )
+    ),
+    collapse = ""
+  ))
   if (!interceptterm) {
-    rearranged_model = update.formula(rearranged_model, ~. + -1)
+    rearranged_model = update.formula(rearranged_model, ~ . + -1)
   }
   rearranged_model
 }
