@@ -75,7 +75,7 @@ Rcpp::List genOptimalDesign(Eigen::MatrixXd initialdesign, const Eigen::MatrixXd
     Eigen::VectorXi initrows = orthogonal_initial(candidatelist, nTrials);
     //If all elements are equal here, nullification algorithm was unable to find a design--return NA
     if(initrows.minCoeff() == initrows.maxCoeff()) {
-      return(List::create(_["indices"] = NumericVector::get_na(), _["model.matrix"] = NumericMatrix::get_na(), _["criterion"] = NumericVector::get_na()));
+      return(List::create(_["indices"] = NumericVector::get_na(), _["model_matrix"] = NumericMatrix::get_na(), _["criterion"] = NumericVector::get_na()));
     }
 
     //Replace non-augmented rows with orthogonal design
@@ -95,7 +95,7 @@ Rcpp::List genOptimalDesign(Eigen::MatrixXd initialdesign, const Eigen::MatrixXd
   }
   //If still no non-singular design, returns NA.
   if (isSingular(initialdesign)) {
-    return(List::create(_["indices"] = NumericVector::get_na(), _["model.matrix"] = NumericMatrix::get_na(), _["criterion"] = NumericVector::get_na()));
+    return(List::create(_["indices"] = NumericVector::get_na(), _["model_matrix"] = NumericMatrix::get_na(), _["criterion"] = NumericVector::get_na()));
   }
 
   bool found = true;
@@ -531,6 +531,6 @@ Rcpp::List genOptimalDesign(Eigen::MatrixXd initialdesign, const Eigen::MatrixXd
     }
   }
   //return the model matrix and a list of the candidate list indices used to construct the run matrix
-  return(List::create(_["indices"] = candidateRow, _["model.matrix"] = initialdesign, _["criterion"] = newOptimum));
+  return(List::create(_["indices"] = candidateRow, _["model_matrix"] = initialdesign, _["criterion"] = newOptimum));
 }
 
